@@ -118,7 +118,7 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.16.2';
+	return '2.17';
   }
 
   function MinimumCMSVersion()
@@ -688,8 +688,9 @@ EOT;
 	if( !isset($this->_product_cache[$id]) )
 	  {
 		$db = $this->GetDb();
-		$query = "SELECT * FROM ".cms_db_prefix()."module_products
-                     WHERE id = ?";
+		$query = "SELECT p.*,ph.hierarchy_id AS hier_id FROM ".cms_db_prefix()."module_products p
+                  LEFT JOIN ".cms_db_prefix()."module_products_prodtohier ph ON p.id = ph.product_id
+                  WHERE p.id = ?";
 		$row = $db->GetRow( $query, array( $id ) );
 		if(!$row) return FALSE;
 		$this->_product_cache[$id] = $row;
@@ -705,7 +706,7 @@ EOT;
 	$results = array();
 	$db = $this->GetDb();
 	$query = "SELECT * FROM ".cms_db_prefix()."module_products_attribsets
-               WHERE product_id = ?";
+               WHERE product_id = ? ORDER BY attrib_set_id";
 	$dbresult = $db->Execute($query,array($product_id));
 	while( $dbresult && ($row = $dbresult->FetchRow()) )
 	  {
@@ -723,13 +724,13 @@ EOT;
 	$data = array();
 
 	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribsets
-              WHERE product_id = ?';
+              WHERE product_id = ? ORDER BY attrib_set_id';
 	$tmp = $db->GetArray($query,array($product_id));
 	
 
 	$tmp2 = cge_array::extract_field($tmp,'attrib_set_id');
 	$q2 = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes
-            WHERE attrib_set_id IN ('.implode(',',$tmp2).') ORDER BY attrib_set_id ASC';
+            WHERE attrib_set_id IN ('.implode(',',$tmp2).') ORDER BY attrib_id ASC';
 	$tmp3 = $db->GetArray($q2);
 
 	for( $i = 0; $i < count($tmp); $i++ )
