@@ -133,6 +133,10 @@ if (isset($params['submit']))
       {
 	$alias = product_ops::generate_alias($product_name);
       }
+    else
+      {
+	$alias = munge_string_to_url($alias);
+      }
 
     // check for duplicate alias
     if( product_ops::check_alias_used($alias) )
@@ -452,26 +456,29 @@ if (count($categories) > 0)
   }
 
 #Display template
-$this->smarty->assign('startform', $this->CreateFormStart($id, 'addproduct', $returnid, 'post', 'multipart/form-data'));
-$this->smarty->assign('endform', $this->CreateFormEnd());
-$this->smarty->assign('nametext', $this->Lang('name'));
-$this->smarty->assign('inputname', $this->CreateInputText($id, 'product_name', $product_name, 30, 255));
-$this->smarty->assign('pricetext', $this->Lang('price'));
-$this->smarty->assign('inputprice', $this->CreateInputText($id, 'price', $price, 8, 12));
+$smarty->assign('startform', $this->CreateFormStart($id, 'addproduct', $returnid, 'post', 'multipart/form-data'));
+$smarty->assign('endform', $this->CreateFormEnd());
+$smarty->assign('nametext', $this->Lang('name'));
+$smarty->assign('inputname', $this->CreateInputText($id, 'product_name', $product_name, 30, 255));
+$smarty->assign('pricetext', $this->Lang('price'));
+$smarty->assign('inputprice', $this->CreateInputText($id, 'price', $price, 8, 12));
 $smarty->assign('currency_symbol',product_ops::get_currency_symbol());
-$this->smarty->assign('weighttext', $this->Lang('weight'));
-$this->smarty->assign('inputweight', $this->CreateInputText($id, 'weight', $weight, 8, 12));
+$smarty->assign('weighttext', $this->Lang('weight'));
+$smarty->assign('inputweight', $this->CreateInputText($id, 'weight', $weight, 8, 12));
 
-$this->smarty->assign('inputsku',$this->CreateInputText($id,'sku',$sku,10,25));
-$this->smarty->assign('inputalias',$this->CreateInputText($id,'alias',$alias,40,255));
-$this->smarty->assign('weightunits',product_ops::get_weight_units());
-$this->smarty->assign('detailstext', $this->Lang('details'));
-$this->smarty->assign('inputdetails', $this->CreateTextArea(true, $id, $details, 'details', '', '', '', '', '80', '5'));
+$smarty->assign('inputsku',$this->CreateInputText($id,'sku',$sku,10,25));
+$smarty->assign('inputalias',$this->CreateInputText($id,'alias',$alias,40,255));
+$smarty->assign('weightunits',product_ops::get_weight_units());
+$smarty->assign('detailstext', $this->Lang('details'));
+$smarty->assign('inputdetails', $this->CreateTextArea(true, $id, $details, 'details', '', '', '', '', '80', '5'));
 
 if( count($catarray) > 0 )
   {
+    $n = count($catarray)/4;
+    $n = min($n,20);
+    $n = max($n,5);
     $smarty->assign('input_categories',
-      $this->CreateInputSelectList($id,'categories[]',$catarray));
+		    $this->CreateInputSelectList($id,'categories[]',$catarray,array(),$n));
   }
 
 $smarty->assign('taxabletext',$this->Lang('taxable'));
@@ -489,11 +496,23 @@ $smarty->assign('statustext',$this->Lang('status'));
 $smarty->assign('inputstatus',
 		$this->CreateInputDropdown($id,'status',
 					   $statuses,-1,$status));
-$this->smarty->assign('hidden', '');
-$this->smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', lang('submit')));
-$this->smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
-$this->smarty->assign_by_ref('customfields', $fieldarray);
-$this->smarty->assign('customfieldscount', count($fieldarray));
+$smarty->assign('hidden', '');
+$smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', lang('submit')));
+$smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
+$smarty->assign_by_ref('customfields', $fieldarray);
+$smarty->assign('customfieldscount', count($fieldarray));
+
+$smarty->assign('starttabheaders',$this->StartTabHeaders());
+$smarty->assign('tabheader_main',$this->SetTabHeader('main',$this->Lang('product_info')));
+$smarty->assign('tabheader_fields',$this->SetTabHeader('fields',$this->Lang('fields')));
+$smarty->assign('tabheader_advanced',$this->SetTabHeader('advanced',$this->Lang('advanced')));
+$smarty->assign('endtabheaders',$this->EndTabHeaders());
+$smarty->assign('starttabcontent',$this->StartTabContent());
+$smarty->assign('tab_main',$this->StartTab('main'));
+$smarty->assign('tab_fields',$this->StartTab('fields'));
+$smarty->assign('tab_advanced',$this->StartTab('advanced'));
+$smarty->assign('endtab',$this->EndTab());
+$smarty->assign('endtabcontent',$this->EndTabContent());
 
 echo $this->ProcessTemplate('editproduct.tpl');
 
