@@ -56,6 +56,7 @@ if( !function_exists('products_byhierarchy_postprocess') )
     {
       if( is_array($data) )
 	{
+	  $config = cmsms()->GetConfig();
 	  $module = cge_utils::get_module('Products');
 	  $imgdir = cms_join_path($config['uploads_path'],$module->GetName(),'hierarchy');
 
@@ -77,11 +78,11 @@ if( !function_exists('products_byhierarchy_postprocess') )
 
 	      $parms = $params;
 	      $parms['parent'] = $rec['id'];
-	      $rec['down_url'] = $module->CreateURL($id,'hierarchy',$thispage,$parms);
+	      $rec['down_url'] = $module->CreateURL('cntnt01','hierarchy',$thispage,$parms);
 
 	      $parms = $params;
 	      $parms['hierarchyid'] = $rec['id'];
-	      $rec['url'] = $module->CreatePrettyLink($id,'default',$summarypage,'',$parms,'',true);
+	      $rec['url'] = $module->CreatePrettyLink('cntnt01','default',$summarypage,'',$parms,'',true);
 
 	      if( isset($rec['children']) )
 		{
