@@ -40,11 +40,11 @@ if( !isset($gCms) ) exit;
 if( !$this->CheckPermission('Modify Products') ) exit;
 
 $query = 'SELECT * FROM '.cms_db_prefix().'module_products_hierarchy 
-           ORDER by hierarchy';
-$dbr = $db->Execute($query);
+           ORDER by parent_id,hierarchy';
+$dbr = $db->GetArray($query);
 
 $entryarray = array();
-while( $dbr && ($row = $dbr->FetchRow()) )
+foreach( $dbr as $row )
   {
     $row['edit_url'] = $this->CreateURL($id,'admin_edit_hierarchy_item',
 					$returnid,
