@@ -37,6 +37,8 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 if( !isset($gCms) ) exit;
+if (!$this->CheckPermission('Modify Products') ) return;
+
 
 //
 // Setup
@@ -113,7 +115,7 @@ if( isset($params['submit']) )
       {
 	$categories = array();
       }
-    $excludecats = isset($params['input_excludecats'])?1:0;
+    $excludecats = (int)$params['input_excludecats'];
 
     // store them as user preferences
     set_preference($uid,'products_sel_hierarchy',$hierarchy);
@@ -213,7 +215,7 @@ $smarty->assign('input_excludecats',$this->CreateInputYesNoDropdown($id,'input_e
 // Build the query
 //
 $fields = array();
-$fields[] = 'p.*';
+$fields[] = 'DISTINCT p.*';
 $prefix1 = "SELECT <FIELDS> FROM ".cms_db_prefix()."module_products p ";
 $prefix2 = "SELECT count(p.id) AS count FROM ".cms_db_prefix().'module_products p ';
 $where = array();
@@ -250,6 +252,7 @@ if( !empty($hierarchy) )
 	$qparms[] = $long_name;
       }
   }
+
 if( is_array($categories) && count($categories) > 0 )
   {
     $joins[] = 'LEFT OUTER JOIN '.cms_db_prefix().'module_products_product_categories pc
@@ -347,20 +350,21 @@ while ($dbresult && $row = $dbresult->FetchRow())
 	      }
 	  }
       }
-    $onerow = cge_array::to_object($row);
 
-    $onerow->edit_url = $this->CreateURL($id,'editproduct',$returnid,
+    $row['edit_url'] = $this->CreateURL($id,'editproduct',$returnid,
 					 array('compid'=>$row['id']));
-    $onerow->attribslink = $this->CreateImageLink($id,'edit_attribsets',$returnid,
+    $row['attribslink'] = $this->CreateImageLink($id,'edit_attribsets',$returnid,
 						  $this->Lang('edit_attribsets'),
 						  'table_relationship.png',
 						  array('compid'=>$row['id']));
 
-    $onerow->editlink = $this->CreateLink($id, 'editproduct', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/edit.gif', $this->Lang('edit'),'','','systemicon'), array('compid'=>$row['id']));
+    $row['editlink'] = $this->CreateLink($id, 'editproduct', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/edit.gif', $this->Lang('edit'),'','','systemicon'), array('compid'=>$row['id']));
 		
-    $onerow->deletelink = $this->CreateLink($id, 'deleteproduct', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/delete.gif', $this->Lang('delete'),'','','systemicon'), array('compid'=>$row['id']), $this->Lang('areyousure_deleteproduct'));
+    $row['copylink'] = $this->CreateLink($id, 'admin_copyproduct', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/copy.gif', $this->Lang('copy_product'),'','','systemicon'), array('compid'=>$row['id']));
 		
-    $entryarray[] = $onerow;
+    $row['deletelink'] = $this->CreateLink($id, 'deleteproduct', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/delete.gif', $this->Lang('delete'),'','','systemicon'), array('compid'=>$row['id']), $this->Lang('areyousure_deleteproduct'));
+		
+    $entryarray[] = $row;
   }
 	
 $this->smarty->assign_by_ref('items', $entryarray);
