@@ -40,7 +40,7 @@
 
 function products_SearchReindex(&$mod,$module)
 {
-  $db =& $mod->GetDb();
+  $db = $mod->GetDb();
   
   $query = 'SELECT id FROM '.cms_db_prefix().'module_products where status = ?';
   $result = &$db->Execute($query,array('published'));
@@ -54,60 +54,9 @@ function products_SearchReindex(&$mod,$module)
     }
 }
 
-function products_UpdateHierarchyPositions(&$mod)
-{
-  $db =& $mod->GetDb();
-	
-  $query = "SELECT id, name FROM ".cms_db_prefix()."module_products_hierarchy";
-  $dbresult = $db->Execute($query);
-  if( !$dbresult ) { echo $db->sql.'<br/>'; die( $db->ErrorMsg() ); }
-  while ($dbresult && $row = $dbresult->FetchRow())
-    {
-      $current_hierarchy_position = "";
-      $current_long_name = "";
-      $content_id = $row['id'];
-      $current_parent_id = $row['id'];
-      $count = 0;
-		
-      while ($current_parent_id > -1)
-	{
-	  $query = "SELECT id, name, parent_id FROM ".cms_db_prefix()."module_products_hierarchy 
-                     WHERE id = ?";
-	  $row2 = $db->GetRow($query, array($current_parent_id));
-	  if ($row2)
-	    {
-	      $current_hierarchy_position = str_pad($row2['id'], 5, '0', STR_PAD_LEFT) . "." . $current_hierarchy_position;
-	      $current_long_name = $row2['name'] . ' | ' . $current_long_name;
-	      $current_parent_id = $row2['parent_id'];
-	      $count++;
-	    }
-	  else
-	    {
-	      $current_parent_id = 0;
-	    }
-
-	}
-		  
-      if (strlen($current_hierarchy_position) > 0)
-	{
-	  $current_hierarchy_position = substr($current_hierarchy_position, 0, strlen($current_hierarchy_position) - 1);
-	}
-		  
-      if (strlen($current_long_name) > 0)
-	{
-	  $current_long_name = substr($current_long_name, 0, strlen($current_long_name) - 3);
-	}
-	  
-      $query = "UPDATE ".cms_db_prefix()."module_products_hierarchy 
-                  SET hierarchy = ?, long_name = ? WHERE id = ?";
-      $db->Execute($query, array($current_hierarchy_position, $current_long_name, $content_id));
-    }
-}
-
 function products_BuildHierarchyList(&$mod)
 {
-  global $gCms;
-  $db =& $gCms->GetDb();
+  $db = cmsms()->GetDb();
   
   $hierarchy_items = array();
   $hierarchy_items[$mod->Lang('none')] = -1;
@@ -133,7 +82,7 @@ function products_BuildHierarchyList(&$mod)
 
 function products_CreateHierarchyDropdown(&$mod,$id,$name,$selectedvalue)
 {
-  $db =& $mod->GetDb();
+  $db = $mod->GetDb();
   $list = array();
   $list[$mod->Lang('any')] = '';
   $query = 'SELECT * FROM '.cms_db_prefix().'module_products_hierarchy
@@ -286,8 +235,8 @@ function products_ProcessImage(&$mod,$srcname,$wmlocation='default')
 
 function products_DeleteProduct(&$mod,$product_id,$update_search=true)
 {
-  global $gCms;
-  $db =& $gCms->GetDb();
+  $gCms = cmsms();
+  $db = $gCms->GetDb();
 
   // Get the category details
   $query = 'SELECT * FROM '.cms_db_prefix().'module_products WHERE id = ?';
@@ -319,7 +268,7 @@ function products_DeleteProduct(&$mod,$product_id,$update_search=true)
   //Update search index
   if( $update_search )
 	{
-	  $module =& $mod->GetModuleInstance('Search');
+	  $module = $mod->GetModuleInstance('Search');
 	  if ($module != FALSE)
 		{
 		  $module->DeleteWords($mod->GetName(), $product_id, 'product');
