@@ -50,6 +50,7 @@ $lang['confirm_copyattributes'] = 'Any existing attribute sets for this product
 $lang['confirm_delete_hierarchy_node'] = 'Are you sure you want to delete this node?  Any products that are using this node will be set to no hierarchy';
 $lang['confirm_import'] = "Are you sure you really want to do this?\\n\\nImproper settings, or an invalid config file could completely corrupt a currently valid and working system.";
 $lang['copy'] = 'Copy';
+$lang['copy_product'] = 'Copy this product';
 $lang['copy_attrib_sets'] = 'Copy Attribute Sets';
 $lang['copy_category']  = 'Copy Category';
 $lang['createddate'] = 'Created Date';
@@ -88,6 +89,7 @@ $lang['edit_category'] = 'Edit Category';
 $lang['edit_category_fields'] = 'Edit Category Fields for &quot;%s&quot;';
 $lang['edit_hierarchy_item'] = 'Edit Hierarchy Item';
 $lang['error_attribset_exists'] = 'An attribute with that name already exists';
+$lang['error_dberror'] = 'Database error';
 $lang['error_duplicate_sku'] = 'Duplicate SKU value found';
 $lang['error_fieldvalue_empty'] = 'The Field Value cannot be empty';
 $lang['error_fileformat'] = 'File Format Problem';
@@ -291,6 +293,7 @@ $lang['module_description'] = 'A module for managing a catalog of products, thei
 $lang['move_down'] = 'Move Down';
 $lang['move_up'] = 'Move Up';
 $lang['msg_eventhandlers_created'] = 'Event Handlers Created';
+$lang['msg_productcopied'] = 'Product successfully copied.  You are now editing the copy.  Any sku information in the product, and/or attributes has been cleared';
 
 # N
 $lang['name'] = 'Name';
@@ -380,6 +383,7 @@ $lang['preferences'] = 'Preferences';
 $lang['preuninstall'] = 'Removing this module will also remove all associated data, are you sure you want to proceed?';
 $lang['price'] = 'Price';
 $lang['price_adjustment'] = 'Price Adjustment';
+$lang['prefix_copyof'] = 'Copy Of';
 $lang['prevpage'] = '&lt;';
 $lang['product'] = 'Product';
 $lang['productname'] = 'Product Name';
