@@ -12,6 +12,7 @@ $lang['add_category_field'] = 'Assosier Felt med Kategori: &quot;%s&quot;';
 $lang['add_hierarchy_item'] = 'Legg til hierarki artikkel';
 $lang['add_option'] = 'Legg til attributt valg';
 $lang['admin_only'] = 'Kan kun administratorer se denne attributten?';
+$lang['advanced'] = 'Avansert';
 $lang['align_ul'] = 'Topp venstre';
 $lang['align_uc'] = 'Topp senter';
 $lang['align_ur'] = 'Topp h&oslash;yre';
@@ -29,6 +30,7 @@ $lang['areyousure_deleteproduct'] = 'Er du virkelig sikker p&aring; at du vil sl
 $lang['ascending'] = 'Stigende';
 $lang['attribute_name'] = 'Attributt navn';
 $lang['automatic'] = 'Automatisk';
+$lang['btn_setecomhandlers'] = 'Sett Ecommerce hendelses behandlere';
 $lang['byhierarchytemplates'] = 'Hierarki rappormaler';
 $lang['byhierarchytemplate_addedit'] = 'Legg til/rediger Hierarki rappormal';
 $lang['cancel'] = 'Avbryt';
@@ -87,6 +89,7 @@ $lang['error_missingparam'] = 'En n&oslash;dvendig parameter mangler eller er ug
 $lang['error_nameused'] = 'En artikkel med det navnet eksisterer allerede';
 $lang['error_nofieldtype'] = 'Vennligst velg en felttype';
 $lang['error_noname'] = 'Du m&aring; oppgi et navn';
+$lang['error_onequantityfield'] = 'Kun et mengde-felt tillatt';
 $lang['error_onesubscriptionfield'] = 'Bare ett abonnement felt er tillatt';
 $lang['error_permissiondenied'] = 'Tilgang nektet';
 $lang['error_product_aliasused'] = 'Alias som ble oppgitt er allerede i bruk';
@@ -96,12 +99,14 @@ $lang['error_product_skuused'] = 'Dette V.nr.(SKU) er allerede i bruk av et anne
 $lang['error_price_adjustment'] = 'Ugyldig prisjusteringsverdi for enhet %s';
 $lang['error_sku_required'] = 'Vennligst oppgit et unikt V.nr.(SKU) ';
 $lang['error_upload_failed'] = 'Opplasting feilet: %s';
+$lang['exclude_categories'] = 'Ekskluder produkter i de valgte kategoriene fra resultatene';
 $lang['expire_six_months'] = 'Etter seks m&aring;neder';
 $lang['expire_one_year'] = 'Etter ett &aring;r';
 $lang['expire_two_year'] = 'Etter to &aring;r';
 $lang['extra1'] = 'Ekstrafelt 1';
 $lang['extra2'] = 'Ekstrafelt 2';
 $lang['field'] = 'Felt';
+$lang['fields'] = 'Felter';
 $lang['fielddef'] = 'Feltdefinisjon';
 $lang['fielddefs'] = 'Feltdefinisjoner';
 $lang['file'] = 'Fil';
@@ -217,11 +222,14 @@ $lang['info_fieldproblems'] = 'Problemer ble oppdaget under h&aring;ndtering av
 $lang['info_handleimages'] = 'Ved import, om et bilde filnavn blir funnet i en feltkolonne, skal det bli fjernet fra kilde lokasjonen, vannmerket, miniatyrbildet, og felttypen endres til &quot;image&quot;';
 $lang['info_hierpage'] = 'Bruk denne siden for hierarkivisninger. Dene sideID vil ikke bli spesifisert p&aring; webadressen.';
 $lang['info_imagepath'] = 'Stien (relativt til uploads katalogen) hvor bilder referert til i importfilen, kan bli funnet';
+$lang['info_imagestuff_deprecated'] = 'Bildebehandlingsfunksjoner er foreldet og vil bli fjernet i en fremtidig versjon. Bruk CGSmartImage for inline bildebehandling.';
 $lang['info_import_test_passed'] = 'En kort test har blitt utf&oslash;rt p&aring; den spesifiserte innfilen, og alt ser ut til &aring; v&aelig;re i orden.<br/>Dette er ikke en indikasjon p&aring; at det ikke kan v&aelig;re feil i filen.';
 $lang['info_prettyhierurls'] = 'Inkluder hierarki elementnavnet p&aring; URLen';
 $lang['info_price_adjustment'] = 'Gyldige verdier er +-*#.##';
 $lang['info_prodnotfound'] = 'Dette alternativet bestemmer oppf&oslash;rselen til nettstedet hvis en har g&aring;tt rett til produkt-detaljvisning via en nettadresse, og at produktet av en eller annen grunn (deaktivert, slettet, osv.) ikke kan &aring;pnes.';
 $lang['info_publicfield'] = 'Offentlige felt er tilgjengelige &aring; se for alle';
+$lang['info_reorder_content'] = 'Denne operasjonen tillater &aring; dra de enkelte noder i treet for &aring; endre rekkef&oslash;lgen de vises p&aring; i hierarkivisning';
+$lang['info_setecomhandlers'] = 'Denne knappen vil sikre at hendelsesbehandlerne for e-handel hendelser er p&aring; plass. Dette er nyttig om en ber Produktmodulen om &aring; holde styr p&aring; mengde tilgjengelig, men hendingsaktivatorer ikke ble opprettet under installasjon eller oppgradering';
 $lang['label'] = 'Etikett';
 $lang['label_skip'] = 'Hopp over';
 $lang['label_overwrite'] = 'Overskriv';
@@ -233,6 +241,7 @@ $lang['modifieddate'] = 'Endret dato';
 $lang['module_description'] = 'En modul for &aring; behandle en katalog med produkter, dets pris, bilder, osv, og for &aring; tillate brukere &aring; bygge en handlekurv';
 $lang['move_down'] = 'Flytt ned';
 $lang['move_up'] = 'Flytt opp';
+$lang['msg_eventhandlers_created'] = 'Hendelsesbehandlere opprettet';
 $lang['name'] = 'Navn';
 $lang['needpermission'] = 'Du har ikke den n&oslash;dvendige rettigheten: %s';
 $lang['new_category_name'] = 'Nytt kategori navn';
@@ -240,7 +249,10 @@ $lang['nextpage'] = ' >';
 $lang['no'] = 'Nei';
 $lang['nonamegiven'] = 'Ingen navn oppgitt';
 $lang['none'] = 'Ingen';
+$lang['nothing_selectd'] = 'Ingenting valgt';
 $lang['of'] = 'av';
+$lang['operation_cancelled'] = 'Operasjon avbrutt';
+$lang['operation_complete'] = 'Operasjon ferdig';
 $lang['page'] = 'Side';
 $lang['page_of'] = 'Side %s av %s';
 $lang['page_limit'] = 'Side begrensning';
@@ -317,6 +329,7 @@ $lang['product_detail_settings'] = 'Produkt detaljinnstillinger';
 $lang['product_editing_settings'] = 'Produktredigerings innstillinger';
 $lang['product_summary_settings'] = 'Produktsammendrag innstillinger';
 $lang['product_hierarchy'] = 'Produkt hierarki';
+$lang['product_info'] = 'Produktinformasjon';
 $lang['product_manager'] = 'Produkt behandler';
 $lang['progress'] = 'Fremdrift';
 $lang['prompt'] = 'Etikett (sp&oslash;rsm&aring;l/prompt)';
@@ -372,7 +385,9 @@ $lang['prompt_usehierpathurls'] = 'Benytt hierakisti i Product detalj URLer';
 $lang['prompt_weightunits'] = 'Vektenheter';
 $lang['public'] = 'Er dette et offentlig felt?';
 $lang['published'] = 'Publisert';
+$lang['quantity_on_hand'] = 'Mengde tilgjengelig';
 $lang['random'] = 'Tilfeldig';
+$lang['reorder_hierarchy'] = 'Omorganiser hierarki';
 $lang['resettofactory'] = 'Sett tilbake til fabrikkinnstillinger';
 $lang['return'] = 'Tilbake';
 $lang['return_to_top'] = 'Returner til toppen av visningen';
@@ -383,7 +398,10 @@ $lang['search_name'] = 'S&oslash;keegenskapsnavn';
 $lang['search_price'] = 'Prisintervall';
 $lang['searchtemplate_addedit'] = 'Legg til/rediger S&oslash;keskjemamal';
 $lang['searchtemplates'] = 'S&oslash;ke maler';
+$lang['select_all'] = 'Velg alle';
 $lang['select_one'] = 'Velg en';
+$lang['setdraft'] = 'Sett som kladd';
+$lang['setpublished'] = 'Sett som publisert';
 $lang['sku'] = 'V.nr.(SKU)';
 $lang['sort_by'] = 'Sorter etter';
 $lang['sort_order'] = 'Sorteringsrekkef&oslash;lge';
@@ -424,10 +442,11 @@ $lang['view'] = 'Vis';
 $lang['viewable_fields'] = 'Velg brukerdefinerte felter som skal vises i tabellen';
 $lang['watermark_location'] = 'Vannmerke lokasjon';
 $lang['weight'] = 'Vekt';
+$lang['with_selected'] = 'Med valgte';
 $lang['yes'] = 'Ja';
 $lang['qca'] = 'P0-536849115-1307983495210';
-$lang['utma'] = '156861353.1438284364.1309196715.1309554925.1309558965.15';
-$lang['utmz'] = '156861353.1307983495.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.771487945.1315514710.1315743680.1315755952.10';
+$lang['utmz'] = '156861353.1315514710.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.2.10.1315755952';
 ?>
\ No newline at end of file
