@@ -74,18 +74,19 @@ class hierarchy_ops
 
   public static function get_hierarchy_path($hier_id)
   {
-    $hier_info = self::get_hierarchy_info($hier_id);
-    if( !$hier_info ) return FALSE;
-  
-    $tmp = explode('.',$hier_info['hierarchy']);
-    if( !count($tmp) ) return FALSE;
-  
-    $breadcrumbs = array();
-    foreach($tmp as $one)
+    $out = array();
+    while( $hier_id > 0 )
       {
-	$breadcrumbs[] = (int)$one;
+	$out[] = $hier_id;
+
+	$hier_info = self::get_hierarchy_info($hier_id);
+	if( !$hier_info ) break;
+
+	$hier_id = $hier_info['parent_id'];
+	if( $hier_id < 0 ) break;
       }
-    return $breadcrumbs;
+
+    return array_reverse($out);
   }
 
 } // end of class
