@@ -174,7 +174,7 @@ class product_ops
 
     $pretty_url = $module->GetPreference('urlprefix',$module->GetName());
     $done = false;
-    if( $module->GetPreference('usehierpathurls',0) && !empty($product['alias']) && ($hier_id > 0) )
+    if( $module->GetPreference('usehierpathurls',0) && !empty($product['alias']) && ($product['hier_id'] > 0) )
       {
 	$hier_id = self::get_product_hierarchy_id($pid);
 	if( $hier_id )
@@ -189,6 +189,8 @@ class product_ops
 		  }
 		$path = implode('/',$tmp2);
 		
+		$pretty_url .= '/details';
+
 		if( $usereturnid )
 		  {
 		    $pretty_url .= "/$returnid";
@@ -196,7 +198,7 @@ class product_ops
 
 		if( !empty($path) )
 		  {
-		    $pretty_url .= "/details/$path";
+		    $pretty_url .= "/$path";
 		  }
 		
 		$pretty_url .= "/".$product['alias'];
@@ -245,7 +247,9 @@ class product_ops
   {
     $hier_id = self::get_product_hierarchy_id($productid);
     if( $hier_id )
-      return hierarchy_ops::get_hierarchy_path($hier_id);
+      {
+	return hierarchy_ops::get_hierarchy_path($hier_id);
+      }
   }
 
 
